@@ -10,7 +10,11 @@ CONSTRAINTS = "constraints"
 
 class VideoGeneratorCSV(CSVParser.CSVParser):
     """
-        **ApertureDB Video Data loader.**
+    **ApertureDB Video Data loader.**
+
+    .. warning::
+        Deprecated. Use :class:`~aperturedb.VideoDataCSV.VideoDataCSV` instead.
+
 
     .. important::
 
@@ -24,6 +28,8 @@ class VideoGeneratorCSV(CSVParser.CSVParser):
         /home/user/file1.jpg,321423532,dog,321423532
         /home/user/file2.jpg,42342522,cat,4234252
         ...
+
+
     """
 
     def __init__(self, filename, check_video=True):
@@ -37,7 +43,7 @@ class VideoGeneratorCSV(CSVParser.CSVParser):
         self.constraints_keys = [x for x in self.header[1:]
                                  if x.startswith(CSVParser.CONTRAINTS_PREFIX)]
 
-    def __getitem__(self, idx):
+    def getitem(self, idx):
 
         filename   = self.df.loc[idx, HEADER_PATH]
         data = {}
@@ -92,7 +98,8 @@ class VideoGeneratorCSV(CSVParser.CSVParser):
 class VideoLoader(ParallelLoader.ParallelLoader):
     """**ApertureDB Video Loader.**
 
-    This class is to be used in combination with a :class:`~aperturedb.VideoLoader.VideoGeneratorCSV`.
+    This class is to be used in combination with a "generator",
+    for example :class:`~aperturedb.VideoLoader.VideoGeneratorCSV`.
     The generator must be an iterable object that generated `video_data`
     elements.
 
